@@ -28,7 +28,7 @@ import (
 // Make sure the generated names exist
 func TestPetName(t *testing.T) {
 	for i:=0; i<10; i++ {
-		name := PetName(i, "-")
+		name := Generate(i, "-")
 		if name == "" {
 			t.Fatalf("Did not generate a %d-word name, '%s'", i, name)
 		}
